@@ -8,10 +8,7 @@ except ImportError:
 
 from admin_sso import settings
 
-try:
-    User = settings.AUTH_PROFILE_MODULE
-except AttributeError:
-    from django.contrib.auth.models import User
+User = getattr(settings, 'AUTH_USER_MODEL', 'auth.User')
 
 
 class Assignment(models.Model):
